function eof_df(ircaam_dataset,simulation,period1, period2)
% eof_df ++explication between period1 days and period2 days

%+
% module
% ======
%
% ++
%
% DESCRIPTION
% ===========
%
% From olrf_arpege_ \ *simulation*\ _  \ *period1*\ -\ *period2*\ d.80.dat,
% ``eof_df`` compute ++.
%
% 1 Postscript file
% eof_arpege_\ *simulation*\ _ \ *period1*\ -\ *period2*\ d.eps are
% written.
%
% EXAMPLES
% ========
%
% Following line read ``eof_arpege_AfNQIVIV_10-30d.80.dat``,
% compute ++,
% write ``eof_arpege_AfNQIVIV_10-30d.eps``
% ::
%
% >> eof_df('arpege','AfNQIVIV',10,30)
%
% SEE ALSO
% ========
%
% carte_eof_df.m_
%
% .. _carte_eof_df.m : carte_eof_df.m.html
%
% time_serie_eof_df.m_
%
% .. _time_serie_eof_df.m : time_serie_eof_df.m.html
%
% TODO
% ====
%
% improve description
%
% improve file pb
%
% use return function
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% - fplod 2009-02-11T16:27:34Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add try/catch on opening file for reading
%
% - fplod 2009-02-10T14:28:00Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace ndmin by period1 and ndmax by period2
%
% - fplod 2009-02-02T13:45:57Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * created from eof_ircaam_1030.m .m to replace it as well as
%     eof_olr_ircaam_1030_as.m, eof_olr_ircaam_1030_ctl.m, 
%     eof_olr_ircaam_1030_ctl_clim.m, eof_olr_ircaam_1030_tr.m, 
%     eof_olr_ircaam_30100.m, eof_olr_ircaam_30100_as.m, eof_olr_ircaam_30100_ctl.m
%     and eof_olr_ircaam_30100_tr.m
%
%     Days will be now written ``period1``\-``period2d`` (ex: 10-30d) in filenames.
%
%     Dataset ``arpege`` will be forced in output file names.
%
%
%-

global IRCAAM_ID;
global IRCAAM_OD;

if nargin==4
 % ircaam_dataset must be equal to arpege
 if ~strcmp(ircaam_dataset,'arpege')
  disp(['ircaam_dataset = ', ircaam_dataset]);
  error('eee : ircaam_dataset must be equal to arpege');
 end
 if strcmp(ircaam_dataset,'arpege')
  list_simulation={'AfNQIVIV','TrNQIVIV','AsNQIVIV','CtIV','CtCl'};
 end
 switch simulation
 case list_simulation
  % ok
 otherwise
  disp(['simulation = ', simulation]);
  disp(['list_simulation = ', mat2str(list_simulation)]);
  error('eee : simulation must be equal to one of list_simulation');
 end
 clear list_simulation;
 % period1 must be lower than period2
 if (period1 > period2)
  disp(['period1 = ', int2str(period1)]);
  disp(['period2 = ', int2str(period2)]);
  error('eee : period1 must be lower than period2');
 end
else
  usage='usage : eof_df(ircaam_dataset,simulation,period1, period2)';
  disp(usage);
  error('eee : wrong arguments numbers')
end

% period1 and period2 will be used in xx-yyd form in filenames
df = [int2str(period1),'-',int2str(period2),'d'];
clear period1;
clear period2;

close all;

fullfilename=[IRCAAM_ID,'olrf_',ircaam_dataset,'_', simulation, '_', df, '.80.dat']; 
try
 fid=fopen(fullfilename,'r');
catch
 error('eee : File %s not found\n', fullfilename);
end
clear fullfilename;
siz=24*15*3538;
v=fread(fid,siz,'float');
fclose(fid);
olr=reshape(v,360,3538);
clear v;

% calcul de la matrice de covariance
vaudou=zeros(360,360);
for a=1:360;
    for b=1:360;
      clear e d covaria;
      e=olr(b,:);
      d=olr(a,:);
      covaria=cov(e,d);
      vaudou(a,b)=covaria(2,1);
    end;
end;

% on diagonalise la matrice de covariance
[C,L]=eig(vaudou);

fullfilename=[IRCAAM_OD,'eof_',ircaam_dataset,'_', simulation, '_', df, '.mat'];
delete(fullfilename);
save(fullfilename,'C','L','olr');
clear fullfilename;
